Package: aebdata
Title: Access Data from the Atlas do Estado Brasileiro
Version: 0.1.4
Authors@R: 
    person("Hugo", "Macedo", , "aebdata@hhmace.do",
           role = c("aut", "cre", "cph"))
Description: Facilitates access to the data from the Atlas do Estado Brasileiro
    (<https://www.ipea.gov.br/atlasestado/>), maintained by the Instituto de
    Pesquisa Econômica Aplicada (Ipea). It allows users to search for specific
    series, list series or themes, and download data when available.
License: GPL (>= 3)
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 4.2.0)
Suggests: knitr, rmarkdown, stringi, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/ipea/aebdata
BugReports: https://github.com/ipea/aebdata/issues
Imports: httr2, readr, rvest
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-02-03 17:29:48 UTC; B12168223793
Author: Hugo Macedo [aut, cre, cph]
Maintainer: Hugo Macedo <aebdata@hhmace.do>
Repository: CRAN
Date/Publication: 2025-02-03 17:50:02 UTC
Built: R 4.3.3; ; 2025-02-15 13:49:44 UTC; unix
