Package: aebdata
Title: Access Data from the Atlas do Estado Brasileiro
Version: 0.1.6
Authors@R: 
    person("Hugo", "Macedo", , "aebdata@hhmace.do",
           role = c("aut", "cre", "cph"))
Description: Facilitates access to the data from the Atlas do Estado Brasileiro
    (<https://www.ipea.gov.br/atlasestado/>), maintained by the Instituto de
    Pesquisa Econômica Aplicada (Ipea). It allows users to search for specific
    series, list series or themes, and download data when available.
License: GPL (>= 3)
Encoding: UTF-8
Depends: R (>= 4.2.0)
Suggests: knitr, rmarkdown, stringi, testthat (>= 3.0.0)
Config/testthat/edition: 3
URL: https://github.com/ipea/aebdata
BugReports: https://github.com/ipea/aebdata/issues
Imports: cli, httr2, readr, rvest
VignetteBuilder: knitr
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-26 22:17:30 UTC; B12168223793
Author: Hugo Macedo [aut, cre, cph]
Maintainer: Hugo Macedo <aebdata@hhmace.do>
Repository: CRAN
Date/Publication: 2026-05-27 07:00:27 UTC
Built: R 4.5.2; ; 2026-05-27 07:42:20 UTC; unix
