
<!-- README.md is generated from README.Rmd. Please edit that file -->

# aebdata

<!-- badges: start -->

[![R-CMD-check](https://github.com/ipea/aebdata/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/ipea/aebdata/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

The package aebdata is part of an effort by the [Atlas do Estado
Brasileiro](https://www.ipea.gov.br/atlasestado/) to facilitate people’s
access to Brazilian data so that anyone can conduct their analysis. The
data, available in .csv format within the series, can now be downloaded
directly from R.

## Installation

There are three methods to install the aebdata package: one from CRAN
and two from [GitHub](https://github.com/):

``` r
# CRAN

install.packages("aebdata")

# GitHub

# The first is a more verbose and human-readable way, using pak:

# install.packages("pak")
pak::pkg_install("ipea/aebdata")

# The second is a lighter and more programmatic version:

# install.packages("remotes")
remotes::install_github("ipea/aebdata")
```
